@@ -35,3 +35,8 @@ WAGTAIL_METRICS_INDENT_JSON = getattr(settings, 'WAGTAIL_METRICS_INDENT_JSON', N
 WAGTAIL_METRICS_GOOGLE_API_KEY = getattr(settings, 'WAGTAIL_METRICS_GOOGLE_API_KEY', None)
 WAGTAIL_METRICS_SEPARATOR = getattr(settings, 'WAGTAIL_METRICS_SEPARATOR', '__')
 WAGTAIL_METRICS_STREAM_FIELD_KEY = getattr(settings, 'WAGTAIL_METRICS_STREAM_FIELD_KEY', None)
+WAGTAIL_METRICS_VALUE_LIMIT = getattr(settings, 'WAGTAIL_METRICS_VALUE_LIMIT', 50)
+WAGTAIL_METRICS_VALUE_LIMIT_EXCLUDE = getattr(settings, 'WAGTAIL_METRICS_VALUE_LIMIT_EXCLUDE', [
+    'seo_title',
+    'search_description'
+])
